@@ -44,6 +44,7 @@ class Download(object):
         extra_params_json (str): Path to JSON file containing extra parameters to put on end of url OR
         extra_params_yaml (str): Path to YAML file containing extra parameters to put on end of url
         extra_params_lookup (str): Lookup key for parameters. If not given assumes parameters are at root of the dict.
+        headers (Dict): Additional headers to add to request.
         status_forcelist (List[int]): HTTP statuses for which to force retry
         method_whitelist (iterable): HTTP methods for which to force retry. Defaults t0 frozenset(['GET']).
     """
@@ -201,8 +202,8 @@ class Download(object):
         else:
             return [hxltags.get(header, '') for header in headers]
 
-    def normal_setup(self, url, stream=True, post=False, parameters=None, timeout=None):
-        # type: (str, bool, bool, Optional[Dict], Optional[float]) -> requests.Response
+    def normal_setup(self, url, stream=True, post=False, parameters=None, timeout=None, headers=None):
+        # type: (str, bool, bool, Optional[Dict], Optional[float], Optional[Dict]) -> requests.Response
         """Setup download from provided url returning the response
 
         Args:
@@ -211,6 +212,7 @@ class Download(object):
             post (bool): Whether to use POST instead of GET. Defaults to False.
             parameters (Optional[Dict]): Parameters to pass. Defaults to None.
             timeout (Optional[float]): Timeout for connecting to URL. Defaults to None (no timeout).
+            headers (Optional[Dict]): Headers to pass. Defaults to None.
 
         Returns:
             requests.Response: requests.Response object
@@ -221,9 +223,9 @@ class Download(object):
         try:
             if post:
                 full_url, parameters = self.get_url_params_for_post(url, parameters)
-                self.response = self.session.post(full_url, data=parameters, stream=stream, timeout=timeout)
+                self.response = self.session.post(full_url, data=parameters, stream=stream, timeout=timeout, headers=headers)
             else:
-                self.response = self.session.get(self.get_url_for_get(url, parameters), stream=stream, timeout=timeout)
+                self.response = self.session.get(self.get_url_for_get(url, parameters), stream=stream, timeout=timeout, headers=headers)
             self.response.raise_for_status()
         except Exception as e:
             raisefrom(DownloadError, 'Setup of Streaming Download of %s failed!' % url, e)
@@ -280,8 +282,8 @@ class Download(object):
                 f.close()
 
     def download_file(self, url, folder=None, filename=None, overwrite=False,
-                      post=False, parameters=None, timeout=None):
-        # type: (str, Optional[str], Optional[str], bool, bool, Optional[Dict], Optional[float]) -> str
+                      post=False, parameters=None, timeout=None, headers=None):
+        # type: (str, Optional[str], Optional[str], bool, bool, Optional[Dict], Optional[float], Optional[Dict]) -> str
         """Download file from url and store in provided folder or temporary folder if no folder supplied
 
         Args:
@@ -292,16 +294,17 @@ class Download(object):
             post (bool): Whether to use POST instead of GET. Defaults to False.
             parameters (Optional[Dict]): Parameters to pass. Defaults to None.
             timeout (Optional[float]): Timeout for connecting to URL. Defaults to None (no timeout).
+            headers (Optional[Dict]): Headers to pass. Defaults to None.
 
         Returns:
             str: Path of downloaded file
 
         """
-        self.setup(url, stream=True, post=post, parameters=parameters, timeout=timeout)
+        self.setup(url, stream=True, post=post, parameters=parameters, timeout=timeout, headers=headers)
         return self.stream_file(url, folder, filename, overwrite)
 
-    def download(self, url, post=False, parameters=None, timeout=None):
-        # type: (str, bool, Optional[Dict], Optional[float]) -> requests.Response
+    def download(self, url, post=False, parameters=None, timeout=None, headers=None):
+        # type: (str, bool, Optional[Dict], Optional[float], Optional[Dict]) -> requests.Response
         """Download url
 
         Args:
@@ -309,12 +312,13 @@ class Download(object):
             post (bool): Whether to use POST instead of GET. Defaults to False.
             parameters (Optional[Dict]): Parameters to pass. Defaults to None.
             timeout (Optional[float]): Timeout for connecting to URL. Defaults to None (no timeout).
+            headers (Optional[Dict]): Headers to pass. Defaults to None.
 
         Returns:
             requests.Response: Response
 
         """
-        return self.setup(url, stream=False, post=post, parameters=parameters, timeout=timeout)
+        return self.setup(url, stream=False, post=post, parameters=parameters, timeout=timeout, headers=headers)
 
     def get_json(self):
         # type: () -> Any
